@@ -2,17 +2,20 @@ from . import PIL  # noqa: F401
 from . import automissing  # noqa: F401
 from . import autopackages  # noqa: F401
 from . import ctypes  # noqa: F401
-from . import docutils  # noqa: F401
+from . import detect_dunder_file  # noqa: F401
 from . import ftplib  # noqa: F401
-from . import ipython  # noqa: F401
+from . import gcloud  # noqa: F401
 from . import lxml  # noqa: F401
 from . import matplotlib  # noqa: F401
 from . import multiprocessing  # noqa: F401
 from . import opencv  # noqa: F401
+from . import pandas  # noqa: F401
 from . import platformdirs  # noqa: F401
+from . import pydantic  # noqa: F401
 from . import pydoc  # noqa: F401
 from . import pyenchant  # noqa: F401
 from . import pygame  # noqa: F401
+from . import pylsp  # noqa: F401
 from . import pyopengl  # noqa: F401
 from . import pyside  # noqa: F401
 from . import pyside2  # noqa: F401
@@ -24,8 +27,11 @@ from . import shiboken2  # noqa: F401
 from . import sip  # noqa: F401
 from . import six  # noqa: F401
 from . import sphinx  # noqa: F401
+from . import sqlalchemy  # noqa: F401
+from . import sslmod  # noqa: F401
 from . import sysconfig_module  # noqa: F401
 from . import tkinter  # noqa: F401
 from . import virtualenv  # noqa: F401
 from . import wx  # noqa: F401
 from . import xml  # noqa: F401
+from . import zmq  # noqa: F401
